==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/turtle/dialogs_it.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("La vedi? Quella dev'essere quella tartaruga telepatica.")

dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Sì, è così. La tartaruga telepatica.")

dialogId("zel-m-fotky0", "font_small", "Well, I don`t know. Judging from those photos, it could be it.")
dialogStr("Be', non saprei, a giudicare dalle foto potrebbe essere lei.")

dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Non ne sono sicura... e quei poteri telepatici?")

dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Comunque sia dobbiamo portarla fuori dalla stanza.")

dialogId("zel-v-zmistnosti1", "font_big", "Let`s take out that turtle.")
dialogStr("Portiamo fuori quella tartaruga.")

dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Cosa fai?")

dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Cosa hai fatto?")

dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Che significa?")

dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Dove nuoti?")

dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Cosa vorrebbe dire?")

dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Che ti succede?")

dialogId("zel-m-nevim0", "font_small", "I don`t know...")
dialogStr("Non lo so...")

dialogId("zel-m-nevim1", "font_small", "I can`t realize...")
dialogStr("Non riesco a capire...")

dialogId("zel-v-nevim0", "font_big", "I don`t know what`s happening to me...")
dialogStr("Non so cosa mi stia succedendo...")

dialogId("zel-v-nevim1", "font_big", "I didn`t want to...")
dialogStr("Non l'ho fatto apposta...")

dialogId("zel-v-cosedeje", "font_big", "What`s happening to us?")
dialogStr("Che cosa ci sta succedendo?")

dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Cosa potrebbe essere?")

dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("Dev'essere la tartaruga!")

dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Dev'essere la tartaruga!")

dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Dunque non ci sono più dubbi - è questa. Quella che cercavamo!")

dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Indubbiamente dev'essere questa la tartaruga che cercavamo!")

dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Quella belva!")

dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Smettila, demonio!")

dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Quando è troppo è troppo!")

dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Ti stai divertendo?")

dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tutte queste forme bizzarre si possono trovare solo nella barriera corallina.")

dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature`s wonders.")
dialogStr("Questi coralli sono delle meraviglie di Madre Natura.")

dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Da dove vengono fuori tante forme così strane?")

dialogId("zel-m-jednoduse", "font_small", "It`s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Semplice - i programmatori creano dei problemi complessi e laciano ai grafici il compito di disegnarli.")

dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Il nostro obiettivo in questa stanza è di portar fuori la tartaruga.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_it.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("La vedi? Quella dev'essere quella tartaruga telepatica.")

dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Sì, è così. La tartaruga telepatica.")

dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("Be', non saprei, a giudicare dalle foto potrebbe essere lei.")

dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Non ne sono sicura... e quei poteri telepatici?")

dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Comunque sia dobbiamo portarla fuori dalla stanza.")

dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Portiamo fuori quella tartaruga.")

dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Cosa fai?")

dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Cosa hai fatto?")

dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Che significa?")

dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Dove nuoti?")

dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Cosa vorrebbe dire?")

dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Che ti succede?")

dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Non lo so...")

dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Non riesco a capire...")

dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Non so cosa mi stia succedendo...")

dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Non l'ho fatto apposta...")

dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Che cosa ci sta succedendo?")

dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Cosa potrebbe essere?")

dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("Dev'essere la tartaruga!")

dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Dev'essere la tartaruga!")

dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Dunque non ci sono più dubbi - è questa. Quella che cercavamo!")

dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Indubbiamente dev'essere questa la tartaruga che cercavamo!")

dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Quella belva!")

dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Smettila, demonio!")

dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Quando è troppo è troppo!")

dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Ti stai divertendo?")

dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tutte queste forme bizzarre si possono trovare solo nella barriera corallina.")

dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Questi coralli sono delle meraviglie di Madre Natura.")

dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Da dove vengono fuori tante forme così strane?")

dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Semplice - i programmatori creano dei problemi complessi e laciano ai grafici il compito di disegnarli.")

dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Il nostro obiettivo in questa stanza è di portar fuori la tartaruga.")
